@@ -1,3 +1,4 @@
+"""Groups factories to be importable from one place."""
 # Copyright (C) 2013 by Clearcode <http://clearcode.cc>
 # and associates (see AUTHORS).
 
@@ -21,10 +22,14 @@ from pytest_dbfixtures.factories.redis import redis_proc, redisdb
 from pytest_dbfixtures.factories.postgresql import postgresql_proc, postgresql
 from pytest_dbfixtures.factories.mysql import mysql_proc
 from pytest_dbfixtures.factories.mysqldb import mysqldb
+from pytest_dbfixtures.factories.elasticsearch import (
+    elasticsearch_proc, elasticsearch
+)
 
 
 __all__ = [
     redis_proc, redisdb,
     postgresql, postgresql_proc,
-    mysql_proc, mysqldb
+    mysql_proc, mysqldb,
+    elasticsearch_proc, elasticsearch
 ]
